<?php
/** 
* ภาษาไทย เวอร์ชั่น 1.3.0 
* 06/01/2555 
* ไฟล์ภาษาไทยสำหรับ PHPBB3 โดย www.mindphp.com และ www.phpbbthailand.com
*
*/ 


if (!defined('IN_PHPBB'))
{
	exit;
}


$help = array(
	array(
		0 => '--',
		1 => 'การเข้าสู่ระบบ และ การสมัครสมาชิก'
	),
	array(
		0 => 'ทำไมเข้าสู่ระบบไม่ได้ ?',
		1 => '&nbsp;&nbsp; 1.คุณได้ทำการสมัครสมาชิกแล้วหรือยัง? คุณต้องสมัครสมาชิกก่อน แล้วจึงสามารถเข้าสู่ระบบได้.
<br/>&nbsp;&nbsp; 2.คุณถูกหวงห้ามไม่ให้เข้าสู่บอร์ดหรือไม่(จะมีข้อความบอกไว้)? ถ้าเป็นเช่นนั้น คุณควรติดต่อ webmaster หรือ administrator ของบอร์ด เพื่อขอทราบเหตุผล.
<br/>&nbsp;&nbsp; 3.ถ้าคุณได้ทำการสมัครสมาชิกแล้ว และไม่ได้ถูกหวงห้าม และคุณยังไม่สามารถเข้าสู่ระบบได้ กรุณาตรวจสอบ username และ password ให้ถูกต้อง.
<br/>&nbsp;&nbsp; 4.ถ้ายังเข้าสู่ระบบไม่ได้อีก กรุณาติดต่อ administrator ของบอร์ด ว่าอาจมีการตั้งค่าที่ไม่ถูกต้องเกิดขึ้นในบอร์ด.'
	),
	array(
		0 => 'จำเป็นต้องสมัครสมาชิกด้วยหรือ?',
		1 => '&nbsp;&nbsp; บางทีอาจไม่จำเป็น ขึ้นอยู่กับ administrator ของบอร์ดจะกำหนดไว้ว่า คุณต้องสมัครสมาชิกก่อนเพื่อโพสต์ข้อความ
   อย่างไรก็ตาม การสมัครสมาชิกจะทำให้คุณสามารถใช้คุณลักษณะเพิ่มเติม ที่ไม่มีให้ใช้ในผู้เยี่ยมชม เช่น การใช้รูปประจำตัว, ข้อความส่วนตัว, ส่ง email ให้ผู้ใช้อื่น, การสมัครเข้าร่วมกลุ่มผู้ใช้ ฯลฯ.การสมัครสมาชิกใช้เวลาเพียงเล็กน้อย ดังนั้นจึงแนะนำให้คุณควรทำการสมัครสมาชิก.'
	),
	array(
		0 => 'ทำไมฉันถึงออกจากระบบโดยอัตโนมัติ?',
		1 => '&nbsp;&nbsp; ถ้าคุณไม่ได้กาถูกหน้า เข้าสู่ระบบโดยอัตโนมัติ ขณะกำลังจะเข้าสู่ระบบ บอร์ดจะยอมให้คุณเข้าสู่ระบบเฉพาะขณะนั้น เพื่อป้องกันไม่ให้คนอื่นเข้ามาใช้ชื่อบัญชีของคุณ.ไม่แนะนำให้คุณเลือกเข้าสู่ระบบโดยอัตโนมัติ ถ้าคุณใช้คอมพิวเตอร์ร่วมกับผู้อื่น เช่น ในห้องสมุด, internet cafe, มหาวิทยาลัย, ฯลฯ'
	),
	array(
		0 => 'จะสั่งไม่ให้แสดงชื่อของฉัน ในรายชื่อผู้ที่กำลัง online ได้อย่างไร? ',
		1 => '&nbsp;&nbsp; ในข้อมูลส่วนตัวของคุณ คุณจะพบตัวเลือก ซ่อนสถานะการ online ของคุณ. ถ้าคุณเลือก ใช่ รายชื่อของคุณจะปรากฏให้คุณและ administrator ของบอร์ด เห็นเท่านั้น และคุณจะถูกนับเป็นผู้ใช้ที่ถูกซ่อน.'
	),
	array(
		0 => 'ฉันลืม password!',
		1 => '&nbsp;&nbsp; อย่าเพิ่งตกใจ! ถ้าคุณลืม password จริงๆ คุณสามารถขออันใหม่ได้. ให้ไปที่หน้าสำหรับเข้าสู่ระบบ แล้วคลิก ลืม password แล้วทำตามขั้นตอนไปเรื่อยๆ'
	),
	array(
		0 => 'สมัครสมาชิกแล้ว แต่เข้าสู่ระบบไม่ได้!',
		1 => '&nbsp;&nbsp; 1.ให้ตรวจสอบว่าคุณกรอก username และ password ที่ถูกต้อง.
   <br/>&nbsp;&nbsp; 2.ถ้าคุณกรอกถูกแล้ว อาจเกิดจากหนึ่งในสองสาเหตุนี้.
   - ถ้าระบบสนับสนุน COPPA ได้ถูกใช้งาน และคุณคลิกที่ลิงค์ ฉันอายุต่ำกว่า 13 ปี ขณะที่คุณกำลังสมัครสมาชิก คุณจะต้องทำตามขั้นตอนที่คุณได้รับ.
   - อาจเป็นเพราะชื่อบัญชีของคุณยังไม่ได้รับการยืนยัน บางบอร์ดจะต้องมีการยืนยันชื่อบัญชีหลังทำการสมัครสมาชิก ทั้งโดยตัวคุณเอง หรือโดย administrator คุณจึงจะสามารถเข้าสู่ระบบได้. เมื่อคุณสมัครสมาชิก ระบบจะบอกคุณเองว่าต้องทำการยืนยันชื่อบัญชีหรือไม่. ถ้าคุณได้รับ email ก็ให้ทำตามขั้นตอนในนั้น, ถ้าคุณไม่ได้รับ อีเมล คุณแน่ใจหรือว่า email ที่คุณกรอกนั้นถูกต้อง? เหตุผลเดียวที่ต้องทำการยืนยันชื่อบัญชีคือ เพื่อลดการปลอมแปลงตัวเข้ามาสู่บอร์ด. ถ้าคุณแน่ใจว่า email นั้นถูกต้อง กรุณาติดต่อ administrator ของบอร์ด.'
	),
	array(
		0 => 'ฉันเคยเข้าสู่ระบบได้ แต่ตอนนี้กลับเข้าไม่ได้?!',
		1 => '&nbsp;&nbsp; สาเหตุส่วนมากคือ
   <br/>&nbsp;&nbsp; 1.คุณป้อน username หรือ password ผิด (กรุณากลับไปตรวจสอบ email ที่คุณได้รับเมื่อคุณสมัครสมาชิก)
   <br/>&nbsp;&nbsp; 2.Administrator ได้ลบชื่อบัญชีของคุณด้วยสาเหตุบางประการ อาจเพราะคุณไม่ได้โพสต์อะไรเลย เป็นเหตุการณ์ปกติที่จะมีการลบผู้ใช้ที่ไม่ได้โพสต์อะไรเลย เพื่อลดขนาดของฐานข้อมูล. กรุณาลองสมัครสมาชิกอีกครั้ง แล้วถามถึงสาเหตุดู.'
	),
	array(
		0 => 'COPPA คืออะไร?',
		1 => '&nbsp;&nbsp; COPPA, หรือ  the Child Online Privacy and Protection Act of 1998, เป็นกฏหมายคุ้มครองผู้บริโภคที่มีอายุต่ำกว่า 13 ปีในการจะกระทำการใดๆ บนเวบไซต์ต้องอยู่ภายใต้การดูแลของผู้ปกครอง, โดยอนุญาตให้เก็บประวัติของเด็กที่มีอายุต่ำกว่า 13 ปี  หากมีความจำเป็นต้องสมัครสมาชิกเพื่อเข้าชมเวบไซต์ แต่ต้องระบุชื่อผู้ปกครองด้วย แต่ phpBB ไม่มีการใช้งานในส่วนนี้  ',
	),
	array(
		0 => 'ทำไมฉันถึงลงทะเีบียนไม่ได้?',
		1 => '&nbsp;&nbsp; เป็นไปได้ว่าผู้ดูแลระบบได้แบน IP Address หรือ ไม่อนุญาตให้ใช้ชื่อ Username นี้ในการสมัคร เจ้าของเวบไซต์อาจจะไม่เปิดในส่วนของการสมัครสมาชิก เพราะไม่ต้องการให้ผู้เยี่ยมชมทำการสมัคร กรุณาติดต่อผู็ดูแลระบบหากต้องการสมัครสมาชิก',
	),
	array(
		0 => 'ข้อความที่ว่า  “ลบคุีกกี้ทั้งหมดของบอร์ดนี้” ทำอะไร ?',
		1 => '&nbsp;&nbsp; “ลบคุีกกี้ทั้งหมดของบอร์ดนี้” จะทำการลบคุ๊กกี๊ทั้งหมดที่ phpBB สร้างขึ้น หากคุณมีปัญหาเรื่องการเข้าใช้งานระบบหรือออกจากระบบ อาจสามารถแก้ไขได้โดยการลบคุ๊กกี้',
	),
	array(
		0 => '--',
		1 => 'ตั้งค่าสมาชิก และ ตั้งค่าต่าง ๆ'
	),
	array(
		0 => 'จะเปลี่ยนแปลงการตั้งค่าได้อย่างไร?',
		1 => '&nbsp;&nbsp; การตั้งค่าทั้งหมดของคุณ (ถ้าคุณได้สมัครสมาชิกแล้ว) จะเก็บไว้ในฐานข้อมูล. ถ้าต้องการเปลี่ยนแปลง ให้คลิกที่ลิงค์ ข้อมูลส่วนตัว (โดยมากจะอยู่ด้านบนของหน้า). ซึ่งจะอนุญาตให้คุณเปลี่ยนแปลงค่าต่างๆ'
	),
	array(
		0 => 'นาฬิกาไม่ตรง!',
		1 => '&nbsp;&nbsp; นาฬิกาในบอร์ด อาจไม่ตรงกับนาฬิกาในประเทศของคุณ ซึ่งคุณควรทำการปรับเวลา โดยเข้าไปแก้ไขการตั้งค่า timezone ในข้อมูลส่วนตัวของคุณ. การแก้ไข timezone จะใช้ได้กับผู้ใช้ที่สมัครสมาชิกแล้วเท่านั้น ถ้าคุณยังไม่ได้สมัครสมาชิก เป็นการดีที่คุณควรจะทำ ก่อนที่คุณจะคำนวณเวลาผิด!'
	),
	array(
		0 => 'เปลี่ยน timezone แล้ว แต่เวลา ก็ยังไม่ตรง!',
		1 => '&nbsp;&nbsp; ถ้าคุณแน่ใจว่าเลือก timezone ถูกต้องแล้ว แต่นาฬิกาก็ยังไม่ตรง อาจเป็นเพราะ daylight savings time (หรือ summer time ซึ่งจะรู้จักดีใน UK และที่อื่นๆ). บอร์ดไม่ได้ถูกออกแบบมาเพื่อรองรับการเปลี่ยนระหว่างนาฬิกาปกติและ daylight time ดังนั้นทุกเดือนของฤดูร้อน นาฬิกาในบอร์ดอาจผิดพลาดไปจากนาฬิกาของคุณประมาณ 1 ชั่วโมง.'
	),
	array(
		0 => 'ภาษาที่ฉันใช้ ไม่ได้อยู่ในรายการให้เลือก!',
		1 => '&nbsp;&nbsp; สาเหตุอาจเกิดจาก administrator ไม่ได้ติดตั้งภาษาของคุณ หรือยังไม่มีการแปลบอร์ดให้เป็นภาษาของคุณ. ลองถาม administrator ของบอร์ดดู เผื่อเขาอาจติดตั้งภาษาที่คุณต้องการได้ ถ้ายังไม่พบภาษาให้ติดตั้ง คุณสามารถแปลด้วยตัวเองได้. คุณจะพบข้อมูลเพิ่มเติมที่เว็บของ phpBB Group (จะเห็นลิงค์ที่ด้านล่างของหน้า)'
	),
	array(
		0 => 'จะแสดงรูปภาพด้านล่าง username อย่างไร?',
		1 => '&nbsp;&nbsp; มีรูปภาพ 2 อย่างที่จะแสดงอยู่ใต้ username เมื่ออ่านข้อความ.
   <br/>&nbsp;&nbsp; 1.รูปภาพแสดงระดับขั้น อาจเป็นรูปดาวหรือกล่องที่จะบอกว่าคุณโพสต์ข้อความมากน้อยเพียงใด.
   <br/>&nbsp;&nbsp; 2.ถัดลงมาอาจเป็นรูปภาพขนาดใหญ่ คือรูปภาพประจำตัว ซึ่งจะบ่งบอกผู้ใช้แต่ละคน. ขึ้นอยู่กับ administrator ของบอร์ด ที่จะยอมให้ใช้รูปภาพประจำตัว และคุณสามารถเลือกวิธีสร้างได้. ถ้าคุณไม่สามารถใช้รูปภาพประจำตัว คุณควรถามเหตุผลจาก admin ของบอร์ด (ซึ่งเราแน่ใจว่าเหตุผลนั้นจะต้องดีพอ!)'
	),
	array(
		0 => 'จะเปลี่ยนระดับขั้นได้อย่างไร?',
		1 => '&nbsp;&nbsp; โดยทั่วไปแล้ว คุณไม่สามารถแก้ไขข้อความแสดงระดับขั้นได้ (ระดับขั้นจะปรากฏอยู่ใต้ username ของคุณในข้อความ และในข้อมูลส่วนตัว ขึ้นอยู่กับรูปแบบที่คุณใช้). บอร์ดส่วนมากใช้ระดับขั้นเพื่อแสดงจำนวนข้อความที่คุณโพสต์ และเพื่อระบุสถานะพิเศษ เช่น moderator และ administrator จะมีระดับขั้นพิเศษ. กรุณาอย่าโพสต์ข้อความมากๆ เพื่อหวังให้ระดับขั้นเพิ่มขึ้น เพราะบางทีคุณอาจถูก moderator หรือ administrator ทำการลดจำนวนการโพสต์ของคุณลง.'
	),
	array(
		0 => 'เมื่อฉันคลิกส่ง email ให้ผู้ใช้อื่น ทำไมระบบถึงถามให้ฉันเข้าสู่ระบบใหม่?',
		1 => '&nbsp;&nbsp; ขออภัย เฉพาะผู้ใช้ที่สมัครสมาชิกแล้วแล้วเท่านั้น ที่สามารถส่ง email ให้ผู้อื่น ผ่านทางแบบฟอร์มส่ง email ของบอร์ด (ถ้า admin อนุญาตให้ใช้คุณลักษณะนี้) เพื่อป้องกันการส่ง email รบกวนผู้อื่น โดยผู้ใช้ที่ไม่ระบุชื่อ.'
	),
	array(
		0 => '--',
		1 => 'การโพสต์ข้อความ'
	),
	array(
		0 => 'จะสร้างหัวข้อใหม่ได้อย่างไร?',
		1 => '&nbsp;&nbsp; คลิกที่ปุ่มสร้างหัวข้อใหม่ ใน บอร์ดหรือในหัวข้อ (คุณอาจต้องสมัครสมาชิกก่อน จึงจะสามารถโพสต์ข้อความได้). คุณจะเห็นข้อความบอกว่าคุณสามารถสร้างหัวข้อใหม่ได้หรือไม่ ที่ด้านล่างของหน้าใน บอร์ดหรือในหัวข้อ (เช่น คุณสามารถสร้างหัวข้อใหม่, คุณสามารถละคะแนน, ฯลฯ.)'
	),
	array(
		0 => 'จะแก้ไขหรือลบข้อความที่โพสต์ได้อย่างไร?',
		1 => '&nbsp;&nbsp; คุณสามารถแก้ไขหรือลบข้อความของคุณเท่านั้น (ยกเว้น admin ของบอร์ด หรือ moderator ของ forum). คุณสามารถแก้ไขข้อความที่โพสต์ (บางครั้งอาจมีการจำกัดจำนวนครั้งของการแก้ไข) โดยคลิกที่ปุ่ม แก้ไข ในข้อความนั้น. ถ้ามีคนตอบข้อความที่คุณโพสต์ไปแล้ว คุณจะเห็นข้อความเล็กๆ ใต้ข้อความของคุณ บอกจำนวนครั้งที่คุณได้ทำการแก้ไข. แต่จะไม่แสดงข้อความเล็กๆนี้ ถ้า moderators หรือ administrators เป็นผู้แก้ไขข้อความนั้น (เขาควรจะบอกสาเหตุที่ต้องแก้ไขไว้ด้วย). กรุณารับทราบว่า ผู้ใช้ปกติจะไม่สามารถลบข้อความที่ได้มีผู้อื่นทำการตอบไปแล้ว.'
	),
	array(
		0 => 'จะเพิ่มลายเซ็นต์ให้กับข้อความที่ฉันโพสต์ได้อย่างไร?',
		1 => '&nbsp;&nbsp; ถ้าจะเพิ่มลายเซ็นต์ให้กับข้อความที่คุณโพสต์ คุณต้องสร้างลายเซ็นต์เสียก่อน ที่ในข้อมูลส่วนตัวของคุณ. เมื่อคุณได้ทำการสร้างแล้ว คุณสามารถกาถูกที่กล่อง เพิ่มลายเซ็นต์ ในหน้าสำหรับการโพสต์. คุณสามารถเพิ่มลายเซ็นต์ให้กับทุกโพสต์ของคุณ โดยการเลือกในข้อมูลส่วนตัวของคุณ (คุณสามารถไม่ใช้ลายเซ็นต์ในบางข้อความ โดยเอาเครื่องหมายถูกออก หน้าการใช้ลายเซ็นต์ ในแบบฟอร์มการโพสต์)'
	),
	array(
		0 => 'จะสร้างแบบสำรวจได้อย่างไร?',
		1 => '&nbsp;&nbsp; เมื่อคุณสร้างหัวข้อใหม่ (หรือแก้ไขข้อความแรกของหัวข้อ ถ้าคุณมีสิทธิ์) คุณจะเห็นแบบฟอร์ม เพิ่มแบบสำรวจ ใต้แบบฟอร์มกรอกข้อความ (ถ้าคุณหาไม่พบ คุณอาจไม่ได้รับสิทธิ์ให้สร้างแบบสำรวจ). คุณควรกรอกหัวข้อแบบสำรวจ และสร้างตัวเลือกอย่างน้อย 2 ตัวเลือก (การสร้างตัวเลือก ให้พิมพ์ข้อความ แล้วคลิกปุ่ม เพิ่มตัวเลือก. คุณสามารถกำหนดเวลาการใช้แบบสำรวจ, 0 คือไม่มีกำหนดเวลา. จะมีรายการกำหนดเวลาให้คุณเห็น ซึ่ง administrator ของบอร์ดได้ตั้งเอาไว้'
	),
	array(
		0 => 'ทำไมฉันถึงเพิ่มตัวเลือกในแบบสอบถามไม่ได้?',
		1 => '&nbsp;&nbsp; ตัวเลือกในแบบสอบถามถูกจำกัดด้วยผู้ดูแลบอร์ด หากต้องการเพิ่มตัวเลือก กรุณาติดต่อผู้ดูแลบอร์ด'
	),
	array(
		0 => 'จะแก้ไขหรือลบแบบสำรวจได้อย่างไร?',
		1 => '&nbsp;&nbsp; ผู้ที่เป็นคนโพสต์ข้อความ, moderator หรือ admin ของบอร์ด สามารถแก้ไขแบบสำรวจได้. ให้คลิกแก้ไขข้อความแรกของหัวข้อ (ซึ่งจะมีแบบสำรวจอยู่ในนั้น). ถ้ายังไม่มีใครลงคะแนน คุณสามารถลบหรือแก้ไขตัวเลือกของแบบสำรวจได้ แต่ถ้ามีผู้ทำการลงคะแนนแล้ว เฉพาะ moderators หรือ administrators เท่านั้นที่สามารถแก้ไขหรือลบได้. เพื่อป้องกันไม่ให้ผู้ใช้แก้ไขตัวเลือกหลังจากลงคะแนนไปแล้ว'
	),
	array(
		0 => 'ทำไมถึงเข้าไปในบอร์ด ไม่ได้?',
		1 => '&nbsp;&nbsp; บางบอร์ดอาจจำกัดให้กับผู้ใช้บางคนหรือบางกลุ่ม. ถ้าจะเข้าไปดู, อ่าน, โพสต์, ฯลฯ คุณจะต้องได้รับการอนุญาตพิเศษ จาก moderator หรือ admin ของบอร์ด. คุณควรติดต่อเขาเพื่อขออนุญาต'
	),
	array(
		0 => 'ทำไมถึงลงคะแนนในแบบสำรวจไม่ได้?',
		1 => '&nbsp;&nbsp; เฉพาะผู้ใช้ที่สมัครสมาชิกแล้วเท่านั้น ที่สามารถลงคะแนนในแบบสำรวจ (เพื่อป้องกันผลคะแนนที่ไม่ตรงความจริง). ถ้าคุณสมัครสมาชิกแล้ว แต่ยังไม่สามารถลงคะแนนได้ บางทีคุณอาจไม่ได้รับสิทธิ์ให้ลงคะแนน.'
	),
	array(
		0 => 'ทำไมฉันถึงได้รับคำเตือน?',
		1 => '&nbsp;&nbsp; บางบอร์ดผู้ดูแลระบบกำหนดกฏบางอย่างขึ้น ถ้าคุณทำผิดกฏ มันจะเป็นเหตุให้คุณได้รับคำเตือน กรุณาติดต่อผู้ดูแลบอร์ด หากคุณได้รับคำแจ้งเตือน ทาง phpBB ไม่สามารถให้คำเตือนได้ๆ กับคุณได้ นอกจากผู้ดูแลบอร์ด'
		),
	array(
		0 => 'ทำอย่างไร ฉันถึงจะสามารถรายงานการโพสต์แก่ผู้ดูแลกระทู้?',
		1 => '&nbsp;&nbsp; หากผู้ดูแลบอร์ดอนุญาต คุณจะเห็นปุ่มรายงาน เพื่อให้คุณเขียนรายงานได้ เมื่อคุณคลิกจะพบกับขั้นตอนการรายงานต่อไป '
	),
	array(
		0 => 'ปุ่ม “บันทึก” ในการโพสต์กระทู้มีไว้ทำอะไร?',
		1 => '&nbsp;&nbsp; อนุณาตให้บันทึกข้อความเพื่อให้สามารถนำมาแก้ไขหรือใช้งานต่อได้ '
	),
	array(
		0 => 'ทำไมกระทู้ของฉันต้องรอการอนุมัติ?',
		1 => '&nbsp;&nbsp; ผู้ดูแลบอร์ดต้องการกรอกข้อความที่คุณโพสต์ก่อน อาจเป็นไปได้ว่าผู้ดุแลบอร์ดให้คุณไปอยู่ในกลุ่มผู้ใช้งานที่ต้องการการตรวจสอบก่อน กรุณาติดต่อผู้ดูแลบอร์ดสำหรับรายละเอียด'
	),
	array(
		0 => 'ทำอย่างไรฉันถึงจะดันกระทู้ได้?',
		1 => '&nbsp;&nbsp; โดยการคลิกที่  “ดันกระทู้” จะแสดง  “ดันกระทู้” นั้นคือกระทู้ที่คุณต้องการได้ไปแสดงด้านบนสุดของบอร์ดแล้วอย่างไรก็ตาม  หากคุณไม่เห็นกระทู้นั้น ให้ลองอ่านกฏของบอร์ดว่าอนุญาตในส่วนนี้หรือไม่ หรือไม่ให้คุณลองดำเนินการอีกครั้ง'
	),
	array(
		0 => '--',
		1 => 'รูปแบบและชนิดของหัวข้อ'
	),
	array(
		0 => 'BBCode คืออะไร?',
		1 => '&nbsp;&nbsp; BBCode คือส่วนเพิ่มเติมพิเศษของภาษา HTML. คุณสามารถใช้ BBCode ถ้า administrator อนุญาต (คุณสามารถสั่งไม่ให้ใช้ BBCode ในแต่ละข้อความโพสต์ ได้ที่แบบฟอร์มสำหรับพิมพ์ข้อความโพสต์). BBCode จะคล้ายกับรูปแบบ HTML คือคำสั่งจะอยู่ในเครื่องหมาย [ และ ] แทนเครื่องหมาย < และ> ซึ่งจะใช้ควบคุมข้อความที่อยู่ระหว่างคำสั่งเปิดและปิด. คุณมารถอ่านข้อมูลเพิ่มเติมของ BBCode ได้ที่หน้าสำหรับโพสต์ข้อความ.'
	),
	array(
		0 => 'ใช้ภาษา HTML ได้ไหม?',
		1 => '&nbsp;&nbsp; ขึ้นอยู่กับ administrator ว่าจะอนุญาตด้วยหรือไม่ ซึ่งเขามีสิทธิ์ควบคุมได้ทั้งหมด. ถ้าคุณได้รับอนุญาตให้ใช้ คุณจะพบว่าสามารถใช้คำสั่ง HTML ได้เพียงบางคำสั่งเท่านั้น. เพื่อ ความปลอดภัย ในการป้องกันผู้ใช้ ที่พยายามรบกวนการทำงานของบอร์ด โดยใช้คำสั่งที่อาจทำลายรูปแบบหรือสร้างปัญหาอื่นๆ. ถ้าการใช้ภาษา HTML ได้ถูกเปิดใช้งาน คุณสามารถสั่งให้ไม่ใช้ภาษา HTML ในแต่ละข้อความโพสต์ ได้ที่แบบฟอร์มสำหรับพิมพ์ข้อความโพสต์.'
	),
	array(
		0 => 'รูปแสดงอารมณ์คืออะไร?',
		1 => '&nbsp;&nbsp; รูปรอยยิ้ม หรือรูปแสดงอารมณ์ เป็นรูปภาพเล็กๆ ที่ใช้เพื่อแสดงอารมณ์ โดยใช้รหัสพิเศษสั้นๆเช่น :) หมายถึงมีความสุข, :( หมายถึงเศร้า. รายการรูปแสดงอารมณ์ทั้งหมดจะอยู่ในแบบฟอร์มสำหรับพิมพ์ข้อความโพสต์. พยายามอย่าใช้รูปรอยยิ้มมากเกินไป เพราะจะทำให้อ่านได้ยาก และ moderator อาจทำการพิจารณาแก้ไขหรือลบข้อความนั้น'
	),
	array(
		0 => 'จะโพสต์รูปได้ไหม?',
		1 => '&nbsp;&nbsp; คุณสามารถแสดงรูปในข้อความของคุณได้. ถ้าคุณไม่พบกล่องสำหรับแนบไฟล์ขึ้นบอร์ด คุณสามารถเชื่อมโยงไปยังรูปภาพที่เก็บไว้บน web server อื่นๆได้ เช่น http://www.some-unknown-place.net/my-picture.gif ซึ่งจะต้องไม่เป็นรูปภาพที่ต้องใช้ระบบการอนุญาต เช่น รูปในกล่องจดหมายของ hotmail หรือ yahoo, เว็บที่มีการป้องกันโดยใช้ password, ฯลฯ. คุณไม่สามารถเชื่อมโยงไปยังรูปภาพที่อยู่บนเครื่อง PC ของคุณ (ยกเว้นว่าจะเป็น server สาธารณะ). การแสดงรูปภาพ ให้ใช้ BBCode ด้วยคำสั่ง [img] หรือใช้คำสั่งในภาษา HTML (ถ้าคุณได้รับอนุญาต).'
	),
	array(
		0 => 'ประกาศทั่วไปคืออะไร?',
		1 => '&nbsp;&nbsp; ประกาศทั่วไปจะประกอบไปด้วยข้อมูลที่สำคัญที่ผู้ดูแลบอร์ดต้องการจะบอกคุณ มันจะปรากฏอยู่ด้านบนสุดของทุก  บอร์ดและในส่วนของแป้นควบคุมของแต่ละผู้ใช้งาน'
	),
	array(
		0 => 'ข้อความประกาศ คืออะไร?',
		1 => '&nbsp;&nbsp; ข้อความประกาศ จะมีข้อมูลสำคัญ ที่คุณควรอ่านทันที. ข้อความประกาศ จะปรากฏอยู่ที่ด้านบนของทุกหน้าใน บอร์ดที่มีการโพสต์ไว้. ซึ่งคุณจะสามารถโพสต์ข้อความประกาศได้หรือไม่นั้น ขึ้นอยู่กับการอนุญาตของ administrator.'
	),
	array(
		0 => 'หัวข้อ ปักหมุด คืออะไร?',
		1 => '&nbsp;&nbsp; หัวข้อ ปักหมุด จะปรากฏอยู่ใต้ข้อความประกาศ เฉพาะหน้าแรกเท่านั้น. ซึ่งค่อนข้างสำคัญ ดังนั้นคุณควรอ่านเมื่อมีโอกาส. เช่นเดียวกันกับข้อความประกาศ คือ administrator จะเป็นผู้ทำการอนุญาตให้คุณสามารถโพสต์หัวข้อ ปักหมุด ได้ในแต่ละบอร์ด.'
	),
	array(
		0 => 'หัวข้อถูกล็อก คืออะไร?',
		1 => '&nbsp;&nbsp; หัวข้อถูกล็อก จะถูกกำหนดโดย moderator ของ บอร์ดหรือ administrator ของบอร์ด. คุณไม่สามารถตอบหัวข้อที่ถูกล็อก และแบบสำรวจที่หมดอายุโดยอัตโนมัติ. อาจมีหลายสาเหตุที่ต้องทำการล็อกหัวข้อ.'
	),
	array(
		0 => 'ไอคอนกระทู้คืออะไร?',
		1 => '&nbsp;&nbsp; ไอคอนกระทู้ ผู้เขียนต้องการระบุเพื่อเป็นสัญลักษณ์ หรือเครื่องบอกทางแก่ผู้ใช้ ทั้งนี้ขึ้นอยู่กับผู้ดูแลบอร์ดว่าอนุญาตให้ใช้งานหรือไม่'
	),
	// This block will switch the FAQ-Questions to the second template column
	array(
		0 => '--',
		1 => '--'
	),
		
	array(
		0 => '--',
		1 => 'ระดับผู้ใช้ และกลุ่มผู้ใช้'
	),
	array(
		0 => 'Administrator คืออะไร?',
		1 => '&nbsp;&nbsp; Administrator เป็นผู้ที่มีระดับสูงสุด ที่สามารถควบคุมบอร์ดทั้งหมด สามารถควบคุมการทำงานทุกอย่างของบอร์ด รวมทั้งการอนุญาตต่างๆ, การหวงห้ามผู้ใช้, การสร้างกลุ่มผู้ใช้ หรือ moderators, ฯลฯ และยังมีสิทธิ์ของการเป็น moderator ในทุก forum.'
	),
	array(
		0 => 'Moderator คืออะไร?',
		1 => '&nbsp;&nbsp; Moderator เป็นบุคคล (หรือกลุ่มของบุคคล) ที่มีหน้าที่ตรวจสอบ บอร์ดสามารถแก้ไขหรือลบข้อความ และสามารถล็อก, ปลดล็อก, ย้าย, ลบ และแยกหัวข้อใน บอร์ดที่ได้รับหน้าที่. โดยทั่วไป moderator จะทำการป้องกันการโพสต์ข้อความก่อกวน.'
	),
	array(
		0 => 'กลุ่มผู้ใช้ คืออะไร?',
		1 => '&nbsp;&nbsp; กลุ่มผู้ใช้ เป็นกลุ่มที่ administrator ของบอร์ดทำการจัดตั้งขึ้น. แต่ละผู้ใช้สามารถเป็นสมาชิกในหลายๆกลุ่มพร้อมกัน (ซึ่งแตกต่างจากบอร์ดอื่นๆ) และสามารถกำหนดสิทธิ์กับแต่ละกลุ่มได้. ช่วยให้ administrator สามารถกำหนดให้ผู้ใช้หลายๆคนสามารถเป็น moderators ของแต่ละ บอร์ดได้ง่ายขึ้น หรืออนุญาตให้สมาชิกในกลุ่มสามารถเข้าไปใน บอร์ดส่วนตัว, ฯลฯ.'
	),
	array(
		0 => 'จะเข้าร่วมกลุ่มผู้ใช้ได้อย่างไร?',
		1 => '&nbsp;&nbsp; การเข้าร่วมกลุ่มผู้ใช้ ให้คลิกลิงค์ กลุ่มผู้ใช้ ที่ด้านบนของแต่ละหน้า (ขึ้นอยู่กับรูปแบบที่ใช้) แล้วคุณจะเห็นกลุ่มที่มีทั้งหมด. อาจไม่ใช่ทุกกลุ่มที่เป็น กลุ่มเปิด, บางกลุ่มอาจถูกปิด และอาจถูกซ่อน. ถ้ากลุ่มนั้นเปิด คุณสามารถส่งคำขอเข้าร่วมกลุ่มได้ โดยคลิกที่ปุ่มเข้าร่วมกลุ่ม. moderator ของกลุ่มผู้ใช้นั้นจะต้องทำการอนุญาตให้คุณเสียก่อน, เขาอาจถามถึงเหตุผลในการเข้าร่วมกลุ่มผู้ใช้. กรุณาอย่ารบกวน moderator ของกลุ่ม ถ้าเขาปฏิเสธคำขอของคุณ ด้วยเหตุผลบางประการ.'
	),
	array(
		0 => 'ทำอย่างไรฉันจะกลายเป็นหัวหน้ากลุ่ม?',
		1 => '&nbsp;&nbsp; หัวหน้ากลุ่ม คือเป็นคนที่มีอำนาจในการอนุมัติ เมื่อ กลุ่มผู้ใช้ถูกสร้างโดยผู้ดูแลบอร์ด ถ้าคุณสนใจจะเป็นหัวหน้ากลุ่มหรือสนใจสร้างกลุ่ม คุณต้องติดต่อผู้ดูแลบอร์ด ลองส่งข้อความส่วนตัวถงผู้ดูแลบอร์ด',
	),
	array(
		0 => 'ทำอย่างไง ให้บางกลุ่มผู้ใช้แสดงสีที่แตกต่างกัน ?',
		1 => '&nbsp;&nbsp; สามารถทำได้ โดยให้ผู้ดูแลบอร์ดเป็นคนดำเนินการให้ เพื่อให้เห็นความแตกต่างของกลุ่มผู้ใช้งาน.'
	),
	array(
		0 => 'อะไรคือ “Default usergroup”?',
		1 => '&nbsp;&nbsp; หากคุณเป็นสมาชิกในกลุ่ม ค่าเริ่มต้นต่างๆ จะถูกกำหนดตามกลุ่มนั้น เช่น สีกลุ่ม ช่วงค่าของกลุ่ม ผู้ดูแลบอร์ดจะคือผู้กำหนดสิทธิ์ '
	
	),
	array(
	0 => 'อะไรคือ “รายชื่อสมาชิก” ?',
	1 => '&nbsp;&nbsp; รายชื่อสมาชิกทั้งหมดของเวบบอร์ดนี้อันประกอบด้วย ผู้ดูแลระบบ ผู้ดูแลบอร์ด หรือผู้ใช้งานทั่วไป เป็นต้น'
	),
	array(
		0 => '--',
		1 => 'ข้อความส่วนตัว'
	),
	array(
		0 => 'ส่งข้อความส่วนตัวไม่ได้!',
		1 => '&nbsp;&nbsp; มี 3 สาเหตุ คือ
   <br/>&nbsp;&nbsp; 1.คุณยังไม่ได้สมัครสมาชิก และ/หรือยังไม่ได้เข้าสู่ระบบ
   <br/>&nbsp;&nbsp; 2.Administrator ของบอร์ดไม่อนุญาตให้ทุกคนใช้ข้อความส่วนตัว
   <br/>&nbsp;&nbsp; 3.คุณไม่ได้รับอนุญาตให้ใช้ข้อความส่วนตัว. ในกรณีนี้ คุณควรติดต่อเพื่อขอทราบเหตุผลจาก administrator.'
	),
	array(
		0 => 'ฉันได้รับแต่ข้อความส่วนตัวที่ไม่ต้องการ!',
		1 => '&nbsp;&nbsp; เราสามารถเพิ่มคุณเข้าไปในรายชื่อผู้ที่ไม่ต้องการรับข้อความส่วนตัวได้. แต่ในเวลานี้ ถ้าคุณยังได้รับข้อความส่วนตัวที่ไม่ต้องการจากบางคน ให้คุณแจ้ง admin ของบอร์ด เขาสามารถป้องกันไม่ให้ผู้ใช้นั้นส่งข้อความส่วนตัวได้อีก.'
	),
	array(
		0 => 'ฉันได้รับ email รบกวนจากผู้ใช้ในบอร์ดนี้!',
		1 => '&nbsp;&nbsp; เราขอแสดงความเสียใจเป็นอย่างยิ่ง. Email ที่ถูกส่งจากบอร์ดนี้ จะมีข้อความที่บอกว่าใครเป็นผู้ส่ง. คุณควรส่ง email ที่มีข้อความทั้งหมด ไปให้ administrator ของบอร์ด ซึ่งรวมทั้งส่วนหัวของข้อความด้วย (ส่วนนี้จะบอกว่า email นั้นถูกส่งมาจากใคร) แล้วเขาจะจัดการให้เอง.'
	),
	array(
		0 => '--',
		1 => 'เพื่อนและศัตรู'
	),
	array(
		0 => 'อะไรคือรายชื่อเพื่อนและศัตรูของฉัน?',
		1 => '&nbsp;&nbsp; คุณสามารถจัดการข้อมูลสมาชิกในบอร์ดได้ โดยสามารถระบุให้สมาชิกท่านอื่นๆ เป็นเพื่อนกับคุณได้ เพื่อใช้ในการติดต่อกันได้โดยตรง เช่น การส่งข้อความส่วนตัว การโพสต์ข้อความต่างๆ ในขณะเดียวกันคุณสามารถเพิ่มรายชื่อศัตรูได้ ศัตรูท่านนั้นจะไม่เห็นข้อความที่คุณโพสต์'
	),
	array(
		0 => 'การเพิ่ม/ลบรายชื่อเพื่อนหรือศัตรูทำได้อย่าไร?',
		1 => '&nbsp;&nbsp; คุณสามารถทำได้ 2 วิธี คือ การเพิ่มใน ประวัติของผู้ใช้งานและอีกวิธีคือการเพิ่มในแป้นควบคุมของผู้ใช้ ในการลบข้อมูลก็เช่นเดียวกัน'
	
	),
	array(
		0 => '--',
		1 => 'การค้นหาข้อมูลในฟอรั่ม'
	),
	array(
		0 => 'ฉันต้องการค้นหา บอร์ดหรือกระทู้ต้องทำอย่างไร?',
		1 => '&nbsp;&nbsp; กรอกข้อมูลที่ต้องการค้นหาในส่วนทที่กำหนดไว้เพื่อการค้นหา หากต้องการการค้นหาที่เจาะลึก คลิกที่ “Advance Search” เพื่อทำการค้นหาต่อไป'
	),
	array(
		0 => 'ทำไมผลลัพธ์ของการค้นหาถึงเป็น 0 ?',
		1 => '&nbsp;&nbsp; คำที่คุณใช้ในการค้นหาอาจกว้างเกินไป ลองเปลี่ยนคำอาจช่วยให้คุณค้นหาพบ'
	),
	array(
		0 => 'ทำไมในขณะทำการค้นหาถึงขึ้นหน้าจอว่างเปล่า!?',
		1 => '&nbsp;&nbsp; ผลลัพธ์ของการค้นหามีจำนวนมากเกินไป กรุณาระบุ “Advanced search” เพื่อเลือกเงื่อนไขในการค้นหา'
	),
	array(
	0 => 'หากต้องการค้นหาสมาชิกทำอย่าไง?',
		1 => '&nbsp;&nbsp; ไปที่ “Members” แล้วคลิก “ค้นหาสมาชิก” '
	),
	array(
	0 => 'ต้องการค้นหา บอร์ดหรือ กระทู้ที่ฉันเป็นเข้าของ?',
	1 => '&nbsp;&nbsp; สามารถทำได้โดย คลิกที่  “Search user’s posts” ในแป้นควบคุมของผู้ใช้ หรือในส่วนของประวัติ เพื่อค้นหา บอร์ดหรือกระทู้นั้น '
	),
	array(
		0 => '--',
		1 => 'รับข่าวสารหัวข้อและรายการโปรด'
	),
	array(
		0 => 'ความแตกต่างระหว่า  bookmarking และ subscribing?',
		1 => '&nbsp;&nbsp; Bookmarking ใน phpBB3 จะเหมือนกับ  web browser. คุณไม่สามารถใช้งานได้เมื่อมันมีการแก้ไข แต่จะเข้ามาใช้ได้ในภายหลัง    Subscribing,คือการแก้ไข บอร์ดหรือกระทู้ 
		'
	),
	array(
		0 => 'ฉันสามารถเขียนคำลงท้ายใน บอร์ดหรือ กระทู้ได้อย่างไร?',
		1 => '&nbsp;&nbsp; หากต้องการเขียนคำลงท้าย บอร์ดคลิกที่  “Subscribe forum” . หากต้องการเขียนคำลงท้ายใต้กระทู้กรุณาเลือก  “Subscribe topic” l'
	),
	array(
		0 => 'ต้องการลบคำลงท้าย ต้องทำอย่างไร?',
		1 => '&nbsp;&nbsp; ไปที่แป้นควบคุมของผู้ใช้แล้วกดลบ.'
	),
	array(
		0 => '--',
		1 => 'การแนบไฟล์'
	),
	array(
		0 => 'ไฟล์อะไรบ้างที่สามารถทำเป็นไฟล์แนบในบอร์ดนี้ได้?',
		1 => '&nbsp;&nbsp; ผู้ดูแลบอร์ดเท่านั้นที่มีสิทธ์ในการอนุญาตหรือไม่อนุญาตให้ใช้ไฟล์แนบ กรุณา ติดต่อผู้ดูแลระบบ.'
	),
	array(
		0 => 'หากต้องการหาไฟล์เอกสารแนบของตนเองทำอย่างไร?',
		1 => '&nbsp;&nbsp; สามารถหาได้จากรายการไฟล์ทั้งหมดที่คุณเป็นคนอัพโหลด,'
	),
	array(
		0 => '--',
		1 => 'เกี่ยวกับ phpBB3'
	),
	array(
		0 => 'ใครเป็นคนสร้างบอร์ด?',
		1 => '&nbsp;&nbsp; โปรแกรมนี้พัฒนาจาก <a href="http://www.phpbb.com/">phpBB Group</a>. It is made available under the GNU General Public License and may be freely distributed. See the link for more details.'
	),
	array(
		0 => 'Why isn’t X feature available?',
		1 => '&nbsp;&nbsp; โปรแกรมนี้เป็น ลิขสิทธ์ของ phpBB Group. สาารถเข้าชมเวบไซต์ได้ที่  phpbb.com.'
	),
	array(
		0 => 'ใครที่ฉันสามารถติดต่อสอบถามข้อมูลเกี่ยวกับบอร์ดนี้?',
		1 => '&nbsp;&nbsp; ผู้ดูแลบอร์ดคือคนที่คุณต้อติดต่อเมื่อต้องการข้อมูลหรือติชมเวบบอร์ด (do a <a href="http://www.google.com/search?q=whois">whois lookup</a>) หรือติดต่อจากกลุ่มที่คุณนำเวบบอร์ดนี้ไปวาง '
	),
	array(
		0 => '--',
		1 => 'เกี่ยวกับภาษาไทย ของ phpBB3'
	),
	array(
		0 => 'ใครเป็นคนแปลภาษาไทยให้กับ phpBB3?',
		1 => 'เป็นความร่วมมือของ Webmaster <a href="http://www.mindphp.com" target="_bank" title="บทความสอน php Mysql">Mindphp.com </a> และ <a href="http://www.phpbbthailand.com/" target="_bank" title="สอบถามปัญหาการใช้งาน phpBB3"> phpBBThailand.com </a> โดยทาง Mindphp.com ได้เป็นผู้ออกงบประมาณในการจ้างแปล (ใครต้องการช่วยสนับสนุนเชิญที่<a href="http://www.mindphp.com/forums/viewforum.php?f=6">Mindphp.com </a>) และทาง <a href="http://www.phpbbthailand.com/"> phpBBThailand.com </a> เป็นผู้รวบรวม ช่วยแปลเพิ่มเติมเพื่อความให้ใช้คำอธิบายให้เข้าใจง่ายขึ้น ช่วยตรวจทาน และทำให้ phpBB3 เหมาะกับภาษาไทยให้มากที่สุด '
	),
        array(
                0=>'ไม่ได้เรียนมาทางสายคอมพิวเตอร์สามารถใช้ phpBB3 ได้ไหม?',
                1=>'ไม่ได้เรียนทางสายคอมพิวเตอร์มาโดยตรงก็สามารถติดตั้งและดูแลบริหารเว็บบอร์ดได้ แต่ท่านควรศึกษาหา<a href="http://www.mindphp.com/%E0%B8%84%E0%B8%B9%E0%B9%88%E0%B8%A1%E0%B8%B7%E0%B8%AD/73-%E0%B8%84%E0%B8%B7%E0%B8%AD%E0%B8%AD%E0%B8%B0%E0%B9%84%E0%B8%A3.html" target="_bank" title="ความรู้เกี่ยวกับคำศัพท์">ความรู้เกี่ยวกับคำศัพท์</a> ความรู้คอมพิวเตอร์พื้นฐานเพิ่มเติม',
        ),
	array(
		0 => 'จะสอบถามปัญหาการใช้งาน ภาษาไทยได้ที่ไหน?',
		1 => 'สามารถ สอบถามปัญหาการใช้งาน phpBB3 ได้ที่ <a href="http://www.phpbbthailand.com/" target="_bank" title="สอบถามปัญหาการใช้งาน phpBB3"> phpBBThailand.com </a> ที่นี่มีคำถามและสมาชิกที่ใช้ phpBB3 อยู่มากมาย'
	)			
);

?>